import { AbstractSession } from "@zowe/imperative";
import { ISearchJobsParms } from "./doc/input/ISearchJobsParms";
/**
 * Class to handle the searching of z/OS batch job spool output
 * @export
 * @class SearchJobs
 */
export declare class SearchJobs {
    /**
     * Search Jobs - Search the spool output of the specified job name for a string or regular expression
     * @static
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {ISearchJobsParms} searchParms - The search parameters for the API call
     * @returns {Promise<string>} - promise that resolves to spool output
     * @throws {ImperativeError} --search-string or --search-regx must be specified
     * @memberof searchJobs
     */
    static searchJobs(session: AbstractSession, searchParms: ISearchJobsParms): Promise<string>;
    /**
     * Search the spool of the specified file for the a search string or regular expression
     * @static
     * @param {AbstractSession} session - z/OSMF connection info
     * @param {string} searchString - The string to search for in the spool output
     * @param {string} searchRegex - The regex to search for in the spool output
     * @param {boolean} caseInsensitive - Specify if a search is case sensitive
     * @param {IJobFile} jobFile - The job spool file to search
     * @param {number} startingLine - The line to start the searching from
     * @returns {Promise<IRestClientResponse>} - promise that resolves to spool output and response headers
     * @memberof searchJobs
     */
    private static searchSpoolContentCommon;
}
//# sourceMappingURL=SearchJobs.d.ts.map